@@ -1,3 +1,4 @@
+
 /*
     yahoocontact.cpp - Yahoo Contact
 
@@ -73,7 +74,6 @@ YahooContact::YahooContact( YahooAccount *account, const QString &userId, const
 	m_manager = 0L;
 	m_account = account;
 	m_YABEntry = 0L;
-	m_stealthed = false;
 	m_receivingWebcam = false;
 	m_sessionActive = false;
 
@@ -108,7 +108,8 @@ QString YahooContact::userId() const
 
 void YahooContact::setOnlineStatus(const Kopete::OnlineStatus &status)
 {
-	if( m_stealthed && status.internalStatus() <= 999)	// Not Stealted -> Stealthed
+	bool isStealthed = stealthed();
+	if( isStealthed && status.internalStatus() <= 999)	// Not Stealted -> Stealthed
 	{
 		Contact::setOnlineStatus(
 			Kopete::OnlineStatus(status.status() ,
@@ -118,7 +119,7 @@ void YahooContact::setOnlineStatus(const Kopete::OnlineStatus &status)
 			status.overlayIcons() + QStringList("yahoo_stealthed") ,
 			i18n("%1|Stealthed", status.description() ) ) );
 	}
-	else if( !m_stealthed && status.internalStatus() > 999 )// Stealthed -> Not Stealthed
+	else if( !isStealthed && status.internalStatus() > 999 )// Stealthed -> Not Stealthed
 		Contact::setOnlineStatus( static_cast< YahooProtocol *>( protocol() )->statusFromYahoo( status.internalStatus() - 1000 ) );
 	else
 		Contact::setOnlineStatus( status );
@@ -127,15 +128,14 @@ void YahooContact::setOnlineStatus(const Kopete::OnlineStatus &status)
 		setStatusMessage( Kopete::StatusMessage() );
 }
 
-void YahooContact::setStealthed( bool stealthed )
+void YahooContact::updateStealthed()
 {
-	m_stealthed = stealthed;
 	setOnlineStatus( onlineStatus() );
 }
 
-bool YahooContact::stealthed()
+bool YahooContact::stealthed() const
 {
-	return m_stealthed;
+	return (m_account->yahooSession()->stealthStatus( m_userId ) == Yahoo::StealthActive );
 }
 
 void YahooContact::serialize(QMap<QString, QString> &serializedData, QMap<QString, QString> &addressBookData)
@@ -208,10 +208,10 @@ Kopete::ChatSession *YahooContact::manager( Kopete::Contact::CanCreateFlags canC
 		Kopete::ContactPtrList m_them;
 		m_them.append( this );
 		m_manager = new YahooChatSession( protocol(), account()->myself(), m_them  );
-		connect( m_manager, SIGNAL( destroyed() ), this, SLOT( slotChatSessionDestroyed() ) );
-		connect( m_manager, SIGNAL( messageSent ( Kopete::Message&, Kopete::ChatSession* ) ), this, SLOT( slotSendMessage( Kopete::Message& ) ) );
-		connect( m_manager, SIGNAL( myselfTyping( bool) ), this, SLOT( slotTyping( bool ) ) );
-		connect( m_account, SIGNAL( receivedTypingMsg( const QString &, bool ) ), m_manager, SLOT( receivedTypingMsg( const QString&, bool ) ) );
+		connect( m_manager, SIGNAL(destroyed()), this, SLOT(slotChatSessionDestroyed()) );
+		connect( m_manager, SIGNAL(messageSent(Kopete::Message&,Kopete::ChatSession*)), this, SLOT(slotSendMessage(Kopete::Message&)) );
+		connect( m_manager, SIGNAL(myselfTyping(bool)), this, SLOT(slotTyping(bool)) );
+		connect( m_account, SIGNAL(receivedTypingMsg(QString,bool)), m_manager, SLOT(receivedTypingMsg(QString,bool)) );
 		connect( this, SIGNAL(displayPictureChanged()), m_manager, SLOT(slotDisplayPictureChanged()));
 	}
 
@@ -271,6 +271,17 @@ QString YahooContact::prepareMessage( const QString &messageText )
 		}
 	}
 
+	// find and remove background color formattings (not supported)
+	regExp.setPattern( "<span([^>]*)background-color:#([0-9a-zA-Z]*)([^>]*)>(.*)</span>" );
+	pos = 0;
+	while ( pos >= 0 ) {
+		pos = regExp.indexIn( messageText, pos );
+		if ( pos >= 0 ) {
+			pos += regExp.matchedLength();
+			newMsg.replace( regExp, QLatin1String("<span\\1\\3>\\4</span>" ) );
+		}
+	}
+
 	// find and replace Color-formattings
 	regExp.setPattern( "<span([^>]*)color:#([0-9a-zA-Z]*)([^>]*)>(.*)</span>" );
 	pos = 0;
@@ -365,7 +376,7 @@ void YahooContact::slotSendMessage( Kopete::Message &message )
 void YahooContact::sendFile( const KUrl &sourceURL, const QString &fileName, uint fileSize )
 {
 	Kopete::TransferManager::transferManager()->sendFile( sourceURL, fileName, fileSize,
-			false, this, SLOT(slotSendFile( const KUrl & )) );
+			false, this, SLOT(slotSendFile(KUrl)) );
 }
 
 void YahooContact::slotTyping(bool isTyping_ )
@@ -390,7 +401,7 @@ QList<KAction*> *YahooContact::customContextMenuActions()
 	if ( !m_webcamAction )
 	{
 		m_webcamAction = new KAction( KIcon("webcamreceive"), i18n( "View &Webcam" ), this );
-		connect( m_webcamAction, SIGNAL( triggered(bool) ), this, SLOT( requestWebcam() ) );
+		connect( m_webcamAction, SIGNAL(triggered(bool)), this, SLOT(requestWebcam()) );
 	}
 	if ( isReachable() )
 		m_webcamAction->setEnabled( true );
@@ -402,7 +413,7 @@ QList<KAction*> *YahooContact::customContextMenuActions()
 	if( !m_inviteWebcamAction )
 	{
 		m_inviteWebcamAction = new KAction( KIcon("webcamsend"), i18n( "Invite to view your Webcam" ), this );
-		connect( m_inviteWebcamAction, SIGNAL( triggered(bool) ), this, SLOT( inviteWebcam() ) );
+		connect( m_inviteWebcamAction, SIGNAL(triggered(bool)), this, SLOT(inviteWebcam()) );
 	}
 	if ( isReachable() )
 		m_inviteWebcamAction->setEnabled( true );
@@ -414,7 +425,7 @@ QList<KAction*> *YahooContact::customContextMenuActions()
 	if ( !m_buzzAction )
 	{
 		m_buzzAction = new KAction( KIcon("bell"), i18n( "&Buzz Contact" ), this);
-		connect( m_buzzAction, SIGNAL( triggered(bool) ), this, SLOT( buzzContact() ) );
+		connect( m_buzzAction, SIGNAL(triggered(bool)), this, SLOT(buzzContact()) );
 	}
 	if ( isReachable() )
 		m_buzzAction->setEnabled( true );
@@ -426,7 +437,7 @@ QList<KAction*> *YahooContact::customContextMenuActions()
 	if ( !m_stealthAction )
 	{
 		m_stealthAction = new KAction( KIcon("yahoo_stealthed"), i18n( "&Stealth Setting" ), this );
-		connect( m_stealthAction, SIGNAL( triggered(bool) ), this, SLOT( stealthContact() ) );
+		connect( m_stealthAction, SIGNAL(triggered(bool)), this, SLOT(stealthContact()) );
 	}
 	if ( isReachable() )
 		m_stealthAction->setEnabled( true );
@@ -438,7 +449,7 @@ QList<KAction*> *YahooContact::customContextMenuActions()
 	if ( !m_inviteConferenceAction )
 	{
 		m_inviteConferenceAction = new KAction( KIcon("x-office-contact"), i18n( "&Invite to Conference" ), this ); // icon should probably be "contact-invite", but that doesn't exist... please request an icon on http://techbase.kde.org/index.php?title=Projects/Oxygen/Missing_Icons
-		connect( m_inviteConferenceAction, SIGNAL( triggered(bool) ), this, SLOT( inviteConference() ) );
+		connect( m_inviteConferenceAction, SIGNAL(triggered(bool)), this, SLOT(inviteConference()) );
 	}
 	if ( isReachable() )
 		m_inviteConferenceAction->setEnabled( true );
@@ -450,7 +461,7 @@ QList<KAction*> *YahooContact::customContextMenuActions()
 	if ( !m_profileAction )
 	{
 		m_profileAction = new KAction( KIcon("document-preview"), i18n( "&View Yahoo Profile" ), this );
-		connect( m_profileAction, SIGNAL( triggered(bool) ), this, SLOT( slotUserProfile() ) );
+		connect( m_profileAction, SIGNAL(triggered(bool)), this, SLOT(slotUserProfile()) );
 	}
 	m_profileAction->setEnabled( true );
 	//actions->addAction( "profile_contact", m_profileAction );
@@ -479,7 +490,7 @@ void YahooContact::slotUserInfo()
 	dlg->setData( *m_YABEntry );
 	dlg->setAccountConnected( m_account->isConnected() );
 	dlg->show();
-	QObject::connect( dlg, SIGNAL(saveYABEntry( YABEntry & )), m_account, SLOT(slotSaveYABEntry( YABEntry & )));
+	QObject::connect( dlg, SIGNAL(saveYABEntry(YABEntry&)), m_account, SLOT(slotSaveYABEntry(YABEntry&)));
 }
 
 void YahooContact::slotUserProfile()
@@ -583,10 +594,10 @@ void YahooContact::setDisplayPicture(const QByteArray &data, int checksum)
 	entry.image = QImage::fromData(data);
 	entry = Kopete::AvatarManager::self()->add(entry);
 
-	if (!entry.path.isNull())
+	if (!entry.dataPath.isNull())
 	{
 		setProperty( Kopete::Global::Properties::self()->photo(), QString() );
-		setProperty( Kopete::Global::Properties::self()->photo() , entry.path );
+		setProperty( Kopete::Global::Properties::self()->photo() , entry.dataPath );
 		emit displayPictureChanged();
 	}
 }
@@ -595,8 +606,7 @@ void YahooContact::setDisplayPicture(const QByteArray &data, int checksum)
 void YahooContact::setYABEntry( YABEntry *entry, bool show )
 {
 	kDebug(YAHOO_GEN_DEBUG) << userId();
-	if( m_YABEntry )
-		delete m_YABEntry;
+	delete m_YABEntry;
 
 	m_YABEntry = entry;
 	writeYABEntry();	// Store data in Contact
@@ -618,13 +628,7 @@ void YahooContact::inviteConference()
 
 void YahooContact::inviteWebcam()
 {
-	if ( KStandardDirs::findExe("jasper").isEmpty() )
-	{
-		KMessageBox::queuedMessageBox( Kopete::UI::Global::mainWidget(), KMessageBox::Error,
-			i18n("I cannot find the Jasper image conversion program.\nJasper is required to render the Yahoo webcam images."
-			"\nPlease see %1 for further information.", QString("http://wiki.kde.org/tiki-index.php?page=Kopete%20Webcam%20Support") ) );
-		return;
-	}
+	// TODO: some message if code for local video devices is not present
 	m_account->yahooSession()->sendWebcamInvite( m_userId );
 }
 
@@ -654,33 +658,25 @@ void YahooContact::initWebcamViewer()
 	if ( !m_webcamDialog )
 	{
 		m_webcamDialog = new YahooWebcamDialog( userId(), Kopete::UI::Global::mainWidget() );
-// 		QObject::connect( m_webcamDialog, SIGNAL( closeClicked() ), this, SLOT( closeWebcamDialog() ) );
+// 		QObject::connect( m_webcamDialog, SIGNAL(closeClicked()), this, SLOT(closeWebcamDialog()) );
 
-		QObject::connect( this, SIGNAL( signalWebcamClosed( int ) ),
-		                  m_webcamDialog, SLOT( webcamClosed( int ) ) );
+		QObject::connect( this, SIGNAL(signalWebcamClosed(int)),
+		                  m_webcamDialog, SLOT(webcamClosed(int)) );
 
-		QObject::connect( this, SIGNAL( signalWebcamPaused() ),
-		                  m_webcamDialog, SLOT( webcamPaused() ) );
+		QObject::connect( this, SIGNAL(signalWebcamPaused()),
+		                  m_webcamDialog, SLOT(webcamPaused()) );
 
-		QObject::connect( this, SIGNAL ( signalReceivedWebcamImage( const QPixmap& ) ),
-				m_webcamDialog, SLOT( newImage( const QPixmap& ) ) );
+		QObject::connect( this, SIGNAL (signalReceivedWebcamImage(QPixmap)),
+				m_webcamDialog, SLOT(newImage(QPixmap)) );
 
-		QObject::connect( m_webcamDialog, SIGNAL ( closingWebcamDialog ( ) ),
-				this, SLOT ( closeWebcamDialog ( ) ) );
+		QObject::connect( m_webcamDialog, SIGNAL (closingWebcamDialog()),
+				this, SLOT (closeWebcamDialog()) );
 	}
 	m_webcamDialog->show();
 }
 
 void YahooContact::requestWebcam()
 {
-	if ( KStandardDirs::findExe("jasper").isEmpty() )
-	{
-		KMessageBox::queuedMessageBox( Kopete::UI::Global::mainWidget(), KMessageBox::Error,
-			i18n("I cannot find the jasper image convert program.\njasper is required to render the yahoo webcam images."
-			"\nPlease see %1 for further information.", QString("http://wiki.kde.org/tiki-index.php?page=Kopete%20Webcam%20Support") ) );
-		return;
-	}
-
 	if( !m_webcamDialog )
 		initWebcamViewer();
 	m_account->yahooSession()->requestWebcam( contactId() );
@@ -688,17 +684,17 @@ void YahooContact::requestWebcam()
 
 void YahooContact::closeWebcamDialog()
 {
-	QObject::disconnect( this, SIGNAL( signalWebcamClosed( int ) ),
-	                  m_webcamDialog, SLOT( webcamClosed( int ) ) );
+	QObject::disconnect( this, SIGNAL(signalWebcamClosed(int)),
+	                  m_webcamDialog, SLOT(webcamClosed(int)) );
 
-	QObject::disconnect( this, SIGNAL( signalWebcamPaused() ),
-	                  m_webcamDialog, SLOT( webcamPaused( ) ) );
+	QObject::disconnect( this, SIGNAL(signalWebcamPaused()),
+	                  m_webcamDialog, SLOT(webcamPaused()) );
 
-	QObject::disconnect( this, SIGNAL ( signalReceivedWebcamImage( const QPixmap& ) ),
-	                  m_webcamDialog, SLOT( newImage( const QPixmap& ) ) );
+	QObject::disconnect( this, SIGNAL (signalReceivedWebcamImage(QPixmap)),
+	                  m_webcamDialog, SLOT(newImage(QPixmap)) );
 
-	QObject::disconnect( m_webcamDialog, SIGNAL ( closingWebcamDialog ( ) ),
-	                  this, SLOT ( closeWebcamDialog ( ) ) );
+	QObject::disconnect( m_webcamDialog, SIGNAL (closingWebcamDialog()),
+	                  this, SLOT (closeWebcamDialog()) );
 	if( m_receivingWebcam )
 		m_account->yahooSession()->closeWebcam( contactId() );
 	m_webcamDialog->delayedDestruct();
@@ -790,8 +786,7 @@ void YahooContact::writeYABEntry()
 void YahooContact::readYABEntry()
 {
 	kDebug(YAHOO_GEN_DEBUG) ;
-	if( m_YABEntry )
-		delete m_YABEntry;
+	delete m_YABEntry;
 
 	m_YABEntry = new YABEntry;
 	m_YABEntry->yahooId = userId();
